@@ -4,10 +4,15 @@ assert_length <- function(x, len = 1L) {
   text_x <- deparse(name_x)
   name_len <- substitute(len)
   text_len <- vapply(name_len[-1], deparse, FUN.VALUE = character(1))
-  if(!length(x) %in% len) {
-    stop("Object ", text_x, " must have length ", paste0(text_len, collapse = " or "),
-         ".",
-         call. = FALSE)
+  if (!length(x) %in% len) {
+    stop(
+      "Object ",
+      text_x,
+      " must have length ",
+      paste0(text_len, collapse = " or "),
+      ".",
+      call. = FALSE
+    )
   }
 }
 
@@ -21,18 +26,22 @@ assert_same_length <- function(a, b, allow_one = TRUE) {
   la <- length(a)
   lb <- length(b)
 
-  if(allow_one) {
-    if(la == 1 || lb == 1)
+  if (allow_one) {
+    if (la == 1 || lb == 1) {
       return()
+    }
   }
 
-  if(la != lb) {
-    stop("The length of arg \"",
-         text_a,
-         "\" should equal the length of arg \"",
-         text_b, "\"",
-         if(allow_one) " if both of them have more than one value." else ".",
-         call. = FALSE)
+  if (la != lb) {
+    stop(
+      "The length of arg \"",
+      text_a,
+      "\" should equal the length of arg \"",
+      text_b,
+      "\"",
+      if (allow_one) " if both of them have more than one value." else ".",
+      call. = FALSE
+    )
   }
   return()
 }
@@ -50,24 +59,29 @@ assert_same_nullness <- function(a, b, nonnull = TRUE) {
   null_a <- is.null(a)
   null_b <- is.null(b)
 
-  if(null_a && null_b) {
+  if (null_a && null_b) {
     return(!nonnull)
   }
 
-  if((!null_a) && (!null_b)) {
+  if ((!null_a) && (!null_b)) {
     return(nonnull)
   }
 
-  stop("If one is specified, both \"", text_a, "\" and \"", text_b, "\" need to be specified.",
-       call. = FALSE)
-
+  stop(
+    "If one is specified, both \"",
+    text_a,
+    "\" and \"",
+    text_b,
+    "\" need to be specified.",
+    call. = FALSE
+  )
 }
 
 # Check if elements in x are all unique (no duplicates)
 assert_unique <- function(x) {
   name_x <- substitute(x)
   text_x <- deparse(name_x)
-  if(anyDuplicated(x)) {
+  if (anyDuplicated(x)) {
     stop("Object ", text_x, " cannot contain duplicated values.", call. = FALSE)
   }
 }
@@ -76,7 +90,7 @@ assert_unique <- function(x) {
 assert_no_missing <- function(x) {
   name_x <- substitute(x)
   text_x <- deparse(name_x)
-  if(anyDuplicated(x)) {
+  if (anyDuplicated(x)) {
     stop("Object ", text_x, " cannot contain missing values.", call. = FALSE)
   }
 }
@@ -85,9 +99,14 @@ assert_no_missing <- function(x) {
 assert_class <- function(x, class) {
   name_x <- substitute(x)
   text_x <- deparse(name_x)
-  if(!inherits(x, class)) {
-    stop("Object ", text_x, " must be from class(es): ",
-         paste0(class, collapse = ", "), call. = FALSE)
+  if (!inherits(x, class)) {
+    stop(
+      "Object ",
+      text_x,
+      " must be from class(es): ",
+      paste0(class, collapse = ", "),
+      call. = FALSE
+    )
   }
 }
 
@@ -95,7 +114,7 @@ assert_class <- function(x, class) {
 assert_vector <- function(x) {
   name_x <- substitute(x)
   text_x <- deparse(name_x)
-  if(!is.vector(x)) {
+  if (!is.vector(x)) {
     stop("Object ", text_x, " must be a vector (not a matrix)", call. = FALSE)
   }
 }
